/// <reference types="readdir-enhanced" />
/// <reference types="micromatch" />
/// <reference types="node" />
import micromatch = require('micromatch');
import { IOptions } from '../managers/options';
import { ITask } from '../managers/tasks';
import { Options as IReaddirOptions } from 'readdir-enhanced';
import { Entry, EntryItem } from '../types/entries';
export default abstract class Reader {
    readonly options: IOptions;
    private readonly micromatchOptions;
    private readonly entryFilter;
    private readonly deepFilter;
    constructor(options: IOptions);
    /**
     * The main logic of reading the directories that must be implemented by each providers.
     */
    abstract read(_task: ITask): any;
    /**
     * Returns root path to scanner.
     */
    getRootDirectory(task: ITask): string;
    /**
     * Returns options for reader.
     */
    getReaderOptions(task: ITask): IReaddirOptions;
    /**
     * Returns options for micromatch.
     */
    getMicromatchOptions(): micromatch.Options;
    /**
     * Returns transformed entry.
     */
    transform(entry: Entry): EntryItem;
    /**
     * Returns true if error has ENOENT code.
     */
    isEnoentCodeError(err: NodeJS.ErrnoException): boolean;
}
